@@ -18,7 +18,7 @@ extends 'Zonemaster::Engine::Translator';
 sub translate_tag {
     my ( $self, $hashref ) = @_;
 
-    my $entry = Zonemaster::Engine::Logger::Entry->new( %{ $hashref } );
+    my $entry = Zonemaster::Engine::Logger::Entry->new( { %{ $hashref } } );
     my $octets = Zonemaster::Engine::Translator::translate_tag( $self, $entry );
 
     return decode_utf8( $octets );
